@@ -2,6 +2,12 @@ from django import forms
 from django.utils.translation import ugettext_lazy as _
 from .models import Image
 
+SIZE_CHOICES = (('billboard', _(u'Billboard')),
+                ('small', _(u'Small')),
+                ('medium', _(u'Medium')),
+                ('large', _(u'Large')),
+                ('original', _(u'Original')))
+
 
 class ImageForm(forms.Form):
     image = forms.ImageField(label=_(u'Image'))
@@ -9,21 +15,15 @@ class ImageForm(forms.Form):
         required=False,
         widget=forms.TextInput(attrs={
             'class': 'form-control',
-            'placeholder': _('a short description of the image for screen ' +
-            'readers and search engines'),
+            'placeholder': _('a short description of the image for screen '
+                             'readers and search engines'),
         }),
         label=_(u'Description')
     )
     size = forms.ChoiceField(
         widget=forms.RadioSelect,
-        choices=(
-            ('billboard', _(u'Billboard')),
-            ('small', _(u'Small')),
-            ('medium', _(u'Medium')),
-            ('large', _(u'Large')),
-            ('original', _(u'Original')),
-        ),
-        initial = 'Billboard',
+        choices=SIZE_CHOICES,
+        initial='Billboard',
         label=_(u'Size')
     )
 
@@ -36,13 +36,7 @@ class LibraryForm(forms.Form):
     )
     size = forms.ChoiceField(
         widget=forms.RadioSelect,
-        choices=(
-            ('billboard', _(u'Billboard')),
-            ('small', _(u'Small')),
-            ('medium', _(u'Medium')),
-            ('large', _(u'Large')),
-            ('original', _(u'Original')),
-        ),
-        initial = 'Billboard',
+        choices=SIZE_CHOICES,
+        initial='Billboard',
         label=_(u'Size')
     )
